# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/

# Force bash instead of Debian dash
%global _buildshell /bin/bash

# Work around quirk in OBS about handling defines...
%if 0%{?el7}
%{!?python3_pkgversion: %global python3_pkgversion 36}
%else
%{!?python3_pkgversion: %global python3_pkgversion 3}
%endif

%if 0%{?suse_version}
%define apache_pkg apache2
%define apache_dir /srv/www
%define apache_etc /etc/apache2
%define apache_user wwwrun
%define apache_group www
%define apache_log /var/log/apache2
%define apache_webconfigdir /etc/apache2/conf.d
%define apache_mod_wsgi apache2-mod_wsgi-python%{python3_pkgversion}
%define tftpboot_dir /srv/tftpboot
%define tftpsrv_pkg tftp
%define createrepo_pkg createrepo_c
%define grub2_x64_efi_pkg grub2-x86_64-efi
%define grub2_ia32_efi_pkg grub2-i386-efi
%define system_release_pkg distribution-release
%undefine python_enable_dependency_generator
%undefine python_disable_dependency_generator
%endif

%if 0%{?debian} || 0%{?ubuntu}
%define apache_pkg apache2
%define apache_dir /var/www
%define apache_etc /etc/apache2
%define apache_user www-data
%define apache_group www-data
%define apache_log /var/log/apache2
%define apache_webconfigdir /etc/apache2/conf-available
%define apache_mod_wsgi libapache2-mod-wsgi-py%{python3_pkgversion}
%define tftpboot_dir /var/lib/tftpboot
%define tftpsrv_pkg tftpd-hpa
%define createrepo_pkg createrepo
%define grub2_x64_efi_pkg grub-efi-amd64
%define grub2_ia32_efi_pkg grub-efi-ia32
%define system_release_pkg base-files
%endif

%if 0%{?fedora} || 0%{?rhel}
%define apache_pkg httpd
%define apache_dir /var/www
%define apache_etc /etc/httpd
%define apache_user apache
%define apache_group apache
%define apache_log /var/log/httpd
%define apache_webconfigdir /etc/httpd/conf.d
%define apache_mod_wsgi python%{python3_pkgversion}-mod_wsgi
%define tftpboot_dir /var/lib/tftpboot
%define tftpsrv_pkg tftp-server
%define createrepo_pkg createrepo_c
%define grub2_x64_efi_pkg grub2-efi-x64
%define grub2_ia32_efi_pkg grub2-efi-ia32
%define system_release_pkg system-release
%endif

# Python module package names that differ between SUSE and everybody else... :(
%if 0%{?suse_version}
%define py3_module_cheetah python%{python3_pkgversion}-Cheetah3
%define py3_module_django python%{python3_pkgversion}-Django
%define py3_module_dns python%{python3_pkgversion}-dnspython
%define py3_module_pyyaml python%{python3_pkgversion}-PyYAML
%define py3_module_sphinx python%{python3_pkgversion}-Sphinx
%else
%define py3_module_cheetah python%{python3_pkgversion}-cheetah
%define py3_module_django python%{python3_pkgversion}-django
%define py3_module_dns python%{python3_pkgversion}-dns
%define py3_module_pyyaml python%{python3_pkgversion}-yaml
%define py3_module_sphinx python%{python3_pkgversion}-sphinx
%endif

# Deal with python3-coverage package quirk
%if 0%{?rhel} == 8
# In RHEL 8, python3-coverage doesn't exist, but it's accessible by common virtual provides
%define py3_module_coverage python3dist(coverage)
%else
%define py3_module_coverage python%{python3_pkgversion}-coverage
%endif

# If they aren't provided by a system installed macro, define them
%{!?__python3: %global __python3 /usr/bin/python3}

# To ensure correct byte compilation
%global __python %{__python3}

%if %{_vendor} == "debbuild"
%global devsuffix dev
%else
%global devsuffix devel
%endif

%global __requires_exclude_from ^%{python3_sitelib}/modules/serializer_mongodb.py*$

Name:           cobbler
Version:        3.1.2
Release:        lp152.6.3.1
Summary:        Boot server configurator
URL:            https://cobbler.github.io/

%if %{_vendor} == "debbuild"
Packager:       Cobbler Developers <cobbler@lists.fedorahosted.org>
Group:          admin
%endif
%if 0%{?suse_version}
Group:          Productivity/Networking/Boot/Servers
%else
Group:          Development/System
%endif

License:        GPL-2.0-or-later
Source:         %{name}-%{version}.tar.gz
Source1:        cobbler.rpmlintrc
BuildArch:      noarch
Patch0:         cgi_parse_qs_is_deprecated.diff
Patch1:         refactored_auth_module.diff
Patch2:         load_module_apache_suse_fix.diff
Patch3:         fix-for-old-str.join-usage.diff
Patch4:         remove-redundant-json-suffix.diff

BuildRequires:  git-core
BuildRequires:  %{system_release_pkg}
BuildRequires:  python%{python3_pkgversion}-%{devsuffix}
%if 0%{?suse_version}
BuildRequires:  python-rpm-macros
%endif
%if %{_vendor} == "debbuild"
BuildRequires:  python3-deb-macros
BuildRequires:  apache2-deb-macros

%endif
BuildRequires:  %{py3_module_coverage}
BuildRequires:  python%{python3_pkgversion}-distro
BuildRequires:  python%{python3_pkgversion}-future
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-netaddr
BuildRequires:  %{py3_module_cheetah}
BuildRequires:  %{py3_module_sphinx}
%if 0%{?suse_version}
# Make post-build-checks happy by including these in the buildroot
BuildRequires:  bash-completion
BuildRequires:  %{apache_pkg}
BuildRequires:  %{tftpsrv_pkg}
%endif

%if 0%{?rhel}
# We need these to build this properly, and OBS doesn't pull them in by default for EPEL
BuildRequires:  epel-rpm-macros
%endif
%if 0%{?rhel} && 0%{?rhel} < 9
BuildRequires:  systemd
%endif
%if 0%{?fedora} >= 30 || 0%{?rhel} >= 9 || 0%{?suse_version}
BuildRequires:  systemd-rpm-macros
%endif
%if %{_vendor} == "debbuild"
BuildRequires:  systemd-deb-macros
Requires:       systemd-sysv
Requires(post): python3-minimal
Requires(preun): python3-minimal
%endif
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd


Requires:       %{apache_pkg}
Requires:       %{tftpsrv_pkg}
Requires:       %{createrepo_pkg}
Requires:       fence-agents
Requires:       rsync
Requires:       xorriso
%{?python_enable_dependency_generator}
%if ! (%{defined python_enable_dependency_generator} || %{defined python_disable_dependency_generator})
Requires:       %{py3_module_cheetah}
Requires:       %{py3_module_dns}
Requires:       python%{python3_pkgversion}-future
Requires:       %{apache_mod_wsgi}
Requires:       python%{python3_pkgversion}-netaddr
Requires:       %{py3_module_pyyaml}
Requires:       python%{python3_pkgversion}-requests
Requires:       python%{python3_pkgversion}-simplejson
Requires:       python%{python3_pkgversion}-tornado
Requires:       python%{python3_pkgversion}-distro
Recommends:     python%{python3_pkgversion}-ldap3
%endif


%if 0%{?fedora} || 0%{?rhel}
Requires:       dnf-plugins-core
%endif
%if ! (0%{?rhel} && 0%{?rhel} < 8)
# Not everyone wants bash-completion...?
Recommends:     bash-completion
# syslinux is only available on x86
Recommends:     syslinux
# grub2 efi stuff is only available on x86
Recommends:     %{grub2_x64_efi_pkg}
Recommends:     %{grub2_ia32_efi_pkg}
Recommends:     logrotate
%endif
# https://github.com/cobbler/cobbler/issues/1685
%if %{_vendor} == "debbuild"
Requires:       init-system-helpers
%else
Requires:       /sbin/service
%endif
# No point in having this split out...
Obsoletes:      cobbler-nsupdate < 3.0.99
Provides:       cobbler-nsupdate = %{version}-%{release}

%description
Cobbler is a network install server.  Cobbler supports PXE, ISO
virtualized installs, and re-installing existing Linux machines.
The last two modes use a helper tool, 'koan', that integrates with
cobbler.  There is also a web interface 'cobbler-web'.  Cobbler's
advanced features include importing distributions from DVDs and rsync
mirrors, kickstart templating, integrated yum mirroring, and built-in
DHCP/DNS Management.  Cobbler has a XMLRPC API for integration with
other applications.


%package web
Summary:        Web interface for Cobbler
Requires:       cobbler = %{version}-%{release}
%if ! (%{defined python_enable_dependency_generator} || %{defined python_disable_dependency_generator})
Requires:       %{py3_module_django}
Requires:       %{apache_mod_wsgi}
%endif
%if 0%{?fedora} || 0%{?rhel}
Requires:       mod_ssl
%endif
Requires(post): openssl

%description web
Web interface for Cobbler that allows visiting
http://server/cobbler_web to configure the install server.

%if 0%{?suse_version}
%package tests
Summary:        Unit tests for cobbler
Requires:       cobbler = %{version}-%{release}

%description tests
Unit test files from the Cobbler project
%endif

%prep
%setup
%patch0 -p1
%patch1 -p1
%if 0%{?suse_version}
%patch2 -p1
%endif
%patch3 -p1
%patch4 -p1

%if 0%{?suse_version}
# Set tftpboot location correctly for SUSE distributions
sed -e "s|/var/lib/tftpboot|%{tftpboot_dir}|g" -i cobbler/settings.py config/cobbler/settings
%endif

%build
%py3_build

%install
# bypass install errors ( don't chown in install step)
%py3_install ||:

# cobbler
rm %{buildroot}%{_sysconfdir}/cobbler/cobbler.conf

mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
mv %{buildroot}%{_sysconfdir}/cobbler/cobblerd_rotate %{buildroot}%{_sysconfdir}/logrotate.d/cobblerd

# No VirtualHost definition as it overwrite all the Uyuni RewriteRules configured in conf.d/
mkdir -p %{buildroot}%{_sysconfdir}/apache2/conf.d
mv %{buildroot}%{_sysconfdir}/apache2/vhosts.d/cobbler.conf %{buildroot}%{_sysconfdir}/apache2/conf.d
sed -i 's/^.*VirtualHost.*$//g' %{buildroot}%{_sysconfdir}/apache2/conf.d/cobbler.conf

# Create data directories in tftpboot_dir
mkdir -p %{buildroot}%{tftpboot_dir}/{boot,etc,grub,images{,2},ppc,pxelinux.cfg,s390x}

# systemd
mkdir -p %{buildroot}%{_unitdir}
mv %{buildroot}%{_sysconfdir}/cobbler/cobblerd.service %{buildroot}%{_unitdir}
%if 0%{?suse_version}
ln -sf service %{buildroot}%{_sbindir}/rccobblerd
%endif

# cobbler-web
rm %{buildroot}%{_sysconfdir}/cobbler/cobbler_web.conf

%if 0%{?suse_version}
# cobbler-tests
cp -r tests/ %{buildroot}/%{_datadir}/cobbler/
%endif


%pre
%if %{_vendor} == "debbuild"
if [ "$1" = "upgrade" ]; then
%else
if [ $1 -ge 2 ]; then
%endif
    # package upgrade: backup configuration
    DATE=$(date "+%Y%m%d-%H%M%S")
    if [ ! -d "%{_sharedstatedir}/cobbler/backup/upgrade-${DATE}" ]; then
        mkdir -p "%{_sharedstatedir}/cobbler/backup/upgrade-${DATE}"
    fi
    for i in "config" "snippets" "templates" "triggers" "scripts"; do
        if [ -d "%{_sharedstatedir}/cobbler/${i}" ]; then
            cp -r "%{_sharedstatedir}/cobbler/${i}" "%{_sharedstatedir}/cobbler/backup/upgrade-${DATE}"
        fi
    done
    if [ -d %{_sysconfdir}/cobbler ]; then
        cp -r %{_sysconfdir}/cobbler "%{_sharedstatedir}/cobbler/backup/upgrade-${DATE}"
    fi
fi

%if %{_vendor} == "debbuild"
%post
%{py3_bytecompile_post %{name}}
%{systemd_post cobblerd.service}
%{apache2_module_post proxy_http}

%preun
%{py3_bytecompile_preun %{name}}
%{systemd_preun cobblerd.service}

%postun
%{systemd_postun_with_restart cobblerd.service}

%else
%post
%if 0%{?suse_version}
# Create bootloders into /var/lib/cobbler/loaders
# Other distros might also want to do that
%{_datadir}/%{name}/bin/mkgrub.sh >/dev/null 2>&1
%endif
%systemd_post cobblerd.service

%preun
%systemd_preun cobblerd.service

%postun
%if 0%{?suse_version}
# This is mkgrub.sh cleanup (exeucted above in post):
# remove linked and installed grub loader executables again
if [ -e %{_localstatedir}/lib/cobbler/loaders/.cobbler_postun_cleanup ];then
   for file in $(cat %{_localstatedir}/lib/cobbler/loaders/.cobbler_postun_cleanup);do
       rm -f %{_localstatedir}/lib/cobbler/loaders/$file
   done
   rm -rf %{_localstatedir}/lib/cobbler/loaders/.cobbler_postun_cleanup
fi
%endif
%systemd_postun_with_restart cobblerd.service
%endif

%post web
%if %{_vendor} == "debbuild"
# Work around broken attr support
# Cf. https://github.com/debbuild/debbuild/issues/160
chown %{apache_user}:%{apache_group} %{_datadir}/cobbler/web
mkdir -p %{_sharedstatedir}/cobbler/webui_sessions
chown %{apache_user}:root %{_sharedstatedir}/cobbler/webui_sessions
chmod 700 %{_sharedstatedir}/cobbler/webui_sessions
chown %{apache_user}:%{apache_group} %{apache_dir}/cobbler_webui_content/
%endif
# Change the SECRET_KEY option in the Django settings.py file
# required for security reasons, should be unique on all systems
# Choose from letters and numbers only, so no special chars like ampersand (&).
RAND_SECRET=$(head /dev/urandom | tr -dc 'A-Za-z0-9!' | head -c 50 ; echo '')
sed -i -e "s/SECRET_KEY = ''/SECRET_KEY = \'$RAND_SECRET\'/" %{_datadir}/cobbler/web/settings.py


%files
%license COPYING
%doc AUTHORS.in README.md
%doc docs/developer-guide.rst docs/quickstart-guide.rst docs/installation-guide.rst
%dir %{_sysconfdir}/cobbler
%config(noreplace) %{_sysconfdir}/cobbler/auth.conf
%dir %{_sysconfdir}/cobbler/boot_loader_conf
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/bootcfg_esxi5.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/bootcfg_esxi51.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/bootcfg_esxi55.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/bootcfg_esxi60.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/bootcfg_esxi65.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/bootcfg_esxi67.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/gpxe_system_esxi5.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/gpxe_system_esxi6.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/gpxe_system_freebsd.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/gpxe_system_linux.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/gpxe_system_local.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/gpxe_system_windows.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/grublocal.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/grubprofile.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/grubsystem.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxedefault.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxelocal.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxelocal_ia64.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxeprofile.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxeprofile_arm.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxeprofile_esxi.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxesystem.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxesystem_arm.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxesystem_esxi.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxesystem_ia64.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/pxesystem_ppc.template
%config(noreplace) %{_sysconfdir}/cobbler/boot_loader_conf/yaboot_ppc.template
%config(noreplace) %{_sysconfdir}/cobbler/cheetah_macros
%config(noreplace) %{_sysconfdir}/cobbler/dhcp.template
%config(noreplace) %{_sysconfdir}/cobbler/dnsmasq.template
%config(noreplace) %{_sysconfdir}/cobbler/genders.template
%config(noreplace) %{_sysconfdir}/cobbler/import_rsync_whitelist
%dir %{_sysconfdir}/cobbler/iso
%config(noreplace) %{_sysconfdir}/cobbler/iso/buildiso.template
%config(noreplace) %{_sysconfdir}/cobbler/logging_config.conf
%config(noreplace) %{_sysconfdir}/cobbler/modules.conf
%config(noreplace) %{_sysconfdir}/cobbler/mongodb.conf
%config(noreplace) %{_sysconfdir}/cobbler/named.template
%config(noreplace) %{_sysconfdir}/cobbler/ndjbdns.template
%dir %{_sysconfdir}/cobbler/reporting
%config(noreplace) %{_sysconfdir}/cobbler/reporting/build_report_email.template
%config(noreplace) %{_sysconfdir}/cobbler/rsync.exclude
%config(noreplace) %{_sysconfdir}/cobbler/rsync.template
%config(noreplace) %{_sysconfdir}/cobbler/secondary.template
%config(noreplace) %{_sysconfdir}/cobbler/settings
%dir %{_sysconfdir}/cobbler/settings.d
%config(noreplace) %{_sysconfdir}/cobbler/settings.d/bind_manage_ipmi.settings
%config(noreplace) %{_sysconfdir}/cobbler/settings.d/manage_genders.settings
%config(noreplace) %{_sysconfdir}/cobbler/settings.d/nsupdate.settings
%config(noreplace) %{_sysconfdir}/cobbler/users.conf
%config(noreplace) %{_sysconfdir}/cobbler/users.digest
%config(noreplace) %{_sysconfdir}/cobbler/version
%config(noreplace) %{_sysconfdir}/cobbler/zone.template
%dir %{_sysconfdir}/cobbler/zone_templates
%config(noreplace) %{_sysconfdir}/cobbler/zone_templates/foo.example.com
%config(noreplace) %{_sysconfdir}/logrotate.d/cobblerd
%config(noreplace) %{apache_webconfigdir}/cobbler.conf
%{_bindir}/cobbler
%{_bindir}/cobbler-ext-nodes
%{_bindir}/cobblerd
%{_sbindir}/tftpd.py
%{_sbindir}/fence_ipmitool
%dir %{_datadir}/cobbler
%{_datadir}/cobbler/bin
%{_mandir}/man1/cobbler.1*
%{_mandir}/man5/cobbler.conf.5*
%{_mandir}/man8/cobblerd.8*
%{_datadir}/bash-completion/completions/cobbler
%{python3_sitelib}/cobbler/
%{python3_sitelib}/cobbler-*
%{_unitdir}/cobblerd.service
%if 0%{?suse_version}
%{_sbindir}/rccobblerd
%endif
%{tftpboot_dir}/*
%{apache_dir}/cobbler
%{_sharedstatedir}/cobbler
%exclude %{_sharedstatedir}/cobbler/webui_sessions
%{_localstatedir}/log/cobbler

%files web
%license COPYING
%doc AUTHORS.in README.md
%config(noreplace) %{apache_etc}/vhosts.d/cobbler_web.conf
%if %{_vendor} == "debbuild"
# Work around broken attr support
# Cf. https://github.com/debbuild/debbuild/issues/160
%{_datadir}/cobbler/web
%dir %{_sharedstatedir}/cobbler/webui_sessions
%{apache_dir}/cobbler_webui_content/
%else
%attr(-,%{apache_user},%{apache_group}) %{_datadir}/cobbler/web
%dir %attr(700,%{apache_user},root) %{_sharedstatedir}/cobbler/webui_sessions
%attr(-,%{apache_user},%{apache_group}) %{apache_dir}/cobbler_webui_content/
%endif

%if 0%{?suse_version}
%files tests
%dir /usr/share/cobbler/tests
/usr/share/cobbler/tests/*
%endif

%changelog
* Fri Nov 13 2020 Jochen Breuer <jbreuer@suse.de>
- Remove redundant '.json' suffix
- Added:
  * remove-redundant-json-suffix.diff
* Tue Nov  3 2020 Jochen Breuer <jbreuer@suse.de>
- Fixes usage of str.join()
- Added:
  * fix-for-old-str.join-usage.diff
* Tue Sep 22 2020 Dominik Gedon <dominik.gedon@suse.com>
- Add fence-agents package as requirement
- Fix position of wrong endif
* Tue Sep 15 2020 Alexander Graul <alexander.graul@suse.com>
- Add cobbler-tests subpackage for unit testing for openSUSE/SLE
* Fri Sep 11 2020 Jochen Breuer <jbreuer@suse.de>
- Adds LoadModule definitions for openSUSE/SLE
- Added:
  * load_module_apache_suse_fix.diff
* Wed Sep  9 2020 Dominik Gedon <dominik.gedon@suse.com>
- Switch to new refactored auth module.
- Added:
  * refactored_auth_module.diff
* Mon Sep  7 2020 Jochen Breuer <jbreuer@suse.de>
- Adding tornado dependency for cobbler tftpd again.
* Mon Sep  7 2020 Jochen Breuer <jbreuer@suse.de>
- cgi.parse_qs is deprecated. Using urllib instead.
- Added:
  * cgi_parse_qs_is_deprecated.diff
* Fri Sep  4 2020 Jochen Breuer <jbreuer@suse.de>
- Adds requirement for python-distro
* Fri Sep  4 2020 Jochen Breuer <jbreuer@suse.de>
- Removes Tornado as dependency and only recommends Ldap3
* Thu May 28 2020 Thomas Renninger <trenn@suse.de>
- Bring changelog in sync with Uyuni:
- Fixes template engine selection(bsc#1170462)
  Fixed mainline by commit 33c769e99
  D fix-template-engine-selection.patch
- Fixes a template rendering error (bsc#1169779)
  Fixed mainline by commit 5e5ef6c8c
  D fixes-a-template-rendering-error.patch
- use systemctl to restart cobblerd on logfile rotation (bsc#1169207)
  Mainline logrotate conf file uses already /sbin/service instead of
  outdated: /etc/init.d/cobblerd
- Fix cobbler sync for DHCP or DNS (bsc#1169553)
  Fixed mainline by commit 2d6cfe42da
  D fix_cobbler_sync_for_dhcp_or_dns.diff
- Signatures file now uses "default_autoinstall" which fixes import
  problem happening with some distributions (bsc#1159010)
  Fixed mainline by commit 33d181199f0da1da
- Fix for kernel and initrd detection (bsc#1159010)
  Fixed mainline by commit 872f505f66c50059
* Wed May 27 2020 Enno Gotthold <egotthold@suse.com>
- New:
  * For the distro there is now a parameter remote_boot_initrd and remote_boot_kernel ()
  * For the profile there is now a parameter filename for DHCP. (#2280)
  * Signatures for ESXi 6 and 7 (#2308)
  * The hardlink command is now detected more dynamically and thus more error resistant (#2297)
  * HTTPBoot will now work in some cases out of the bug. (#2295)
  * Additional DNS query for a case where the wrong record was queried in the nsupdate system case (#2285)
- Changes:
  * Enabled a lot of tests, removed some and implemented new. (#2202)
  * Removed not used files from the codebase. (#2302)
  * Exchanged mkisofs to xorrisofs. (#2296)
  * Removed duplicate code. (#2224)
  * Removed unreachable code. (#2223)
  * Snippet creation and deletion now works again via xmlrpc. (#2244)
  * Replace createrepo with createrepo_c. (#2266)
  * Enable Kerberos through having a case sensitive users.conf. (#2272)
- Bugfixes:
  * General various Bugfixes (#2331, )
  * Makefile usage and commands. (#2344, #2304)
  * Fix the dhcp template. (#2314)
  * Creation of the management classes and gPXE. (#2310)
  * Fix the scm_track module. (#2275, #2279)
  * Fix passing the netdevice parameter correctly to the linuxrc. (#2263)
  * powerstatus from cobbler now works thanks to a wrapper for ipmitool. (#2267)
  * In case the LDAP is used for auth, it now works with ADs. (#2274)
  * Fix passthru authentication. (#2271)
- Other:
  * Add Codecov. (#2229)
  * Documentation updates. (#2333, #2326, #2305, #2249, #2268)
  * Buildprocess:
  * Recreation and cleanup of Grub2. (#2278)
  * Fix small errors for openSUSE Leap. (#2233)
  * Fix rpmlint errors. (#2237)
  * Maximum compatibility for debbuild package creation. (#2255, #2292, #2242, #2300)
  * Fixes related to our CI Pipeline (#2254, #2269)
  * Internal Code cleanup (#2273, #2270)
- Breaking Changes:
  * Hash handling in users.digest file. (#2299)
* Mon Feb 24 2020 Thomas Renninger <trenn@suse.de>
- Removed not needed files in obs. This is now all mainline:
  D logrotate_cobbler
  D fix_hardcoded_libpath_for_websession.patch
  D fence_ipmitool.template
  D cobbler_management_mac.diff
  D AUTHORS
- Added source files:
  A cobbler.obsinfo
  A cobbler-rpmlintrc
  D exclude_get-loaders_command.patch
  Spec file is mostly adopted to mainline spec file.
  Still it is not directly extracted from mainline tarball.
  First the remaining diff has to be submitted mainline.
- Change group to Productivity/Networking/Boot/Servers
- Disable any python_*_dependency_generator macros
  According to Tomas Chvatal they are much too experimental yet
  in OBS to be used. They have to be undefined, because of a half
  baken implementation in SLE 15 SP2 build env (defined but not
  properly implemented). At some point of time the introduced
  undefine python_*_dependency_generator
  will be conditionally removed via suse_version.
* Mon Jan 13 2020 Enno Gotthold <egotthold@suse.com>
- Updated to version 3.1.1.
  * Introduce new packaging from upstream
  * Changelog see below
- New:
  * We are now having a cross-distro specfile which can be build in the OBS
    (#2220) - before rewritten it was improved by #2144 & #2174
  * Grub Submenu for net-booting machines (#2217)
  * Building the Cent-OS RPMs in Docker (#2190 #2189)
  * Reintroduced manpage build in setup.py (#2185)
  * mgmt_parameters are now passed to the dhcp template (#2182)
  * Using the standard Pyhton3 logger instead of a custom one (#2160 #2139 #2151)
  * Script for converting the settings file from 3.0.0 to 3.0.1 (#2154)
  * Docs now inside the repo instead of cobbler.github.io and improved with sphinx (#2117)
- Changes:
  * The default tftpboot directory is now /var/lib/tftpboot instead of previously /srv/tftpboot (#2220)
  * Distro signatures were adjusted where necessary (#2219 #2134)
  * Removed requirements.txt and placed the requirements in setup.py (#2204)
  * Display only entries in grub which are from the same arch (#2191 #2216)
  * Change the name of the cobbler manpage form cobbler-cli to cobbler back and move it to section 8 (#2188 #2186)
- Bugfixes:
  * Incremented Version to 3.1.1 from 3.0.1
  * S390 Support was cleaned up (#2207 #2178)
  * PowerPC Support was cleaned up (#2178)
  * Added a missing import while importing a distro with cobbler import (#2201)
  * Fixed a case where a stacktrace would be produced so pass none instead (#2203)
  * Rename of suse_kopts_textmode_overwrite to kops_overwrite to utils (#2143 #2200)
  * Fix rsync subprocess call (#2199 #2179)
  * Fixed an error where the template rendering did not work (#2176)
  * Fixed some cobbler import errors (#2172)
  * Wrong shebang in various scripts (#2148)
  * Fix some imports which fixes errors introduced by the remodularization (#2150 #2153)
- Other:
  * Issue Templates for Github (#2187)
* Tue Nov 26 2019 trenn@suse.de
- Update to latest git HEAD code base
  This version (from mainline so for quite a while already)
  also includes fixes for "bsc#1149075" and bsc#1151875
  These patches are mainline already:
  D kopts-utils-path.diff
  D item-repo-import-fix.diff
  D no-system-in-kopts-call.diff
  This patch is going to be submitted mainline:
  A cobbler_management_mac.diff
- Fix up manpage creation: Do not zip manpages ourselves
  Thanks to namtrac.
* Tue Nov 19 2019 Jochen Breuer <jbreuer@suse.de>
- Fix for cobbler import and buildiso (bsc#1156574)
- Added:
  * kopts-utils-path.diff
  * no-system-in-kopts-call.diff
  * item-repo-import-fix.diff
* Fri Oct 25 2019 trenn@suse.de
- Update to latest git HEAD code base (commit fbebd758)
- Adjusted manpage creation (needs sphinx as BuildRequires)
* Tue Oct  8 2019 trenn@suse.de
- Switch to openSUSE latest_mulitarch_work for shortterm until
  everything is in place and submitted mainline
- started to switch to Sphinx manpage generation, but comment out.
  SuMa people must have done this already somewhere.
- Already mainline:
  D fix_module_renaming.diff
* Wed Sep 18 2019 trenn@suse.de
- Fix cobbler sync for dhcp and dns enabled due to latest module
  renaming patches
* Tue Sep 17 2019 trenn@suse.de
- Update to latest git HEAD
  - Fixes permission denied in apache2 context when trying to write
    cobbler log
  - Fixes a bad import in import_signature (item)
  - Fixes bad shebang bash path in mkgrub.sh (used in post section)
* Wed Sep 11 2019 Christian Vögl <christian.voegl@suse.com>
- Now track Github master branch
  WARNING: This release contains breaking changes for your settings file!
  * Notable changes:
  - Now using standard python logger
  - Updated dhcpd.template
- Removed fix_shebang.patch: now in upstream.
- added -s parameter to fdupes call to prevent hardlink across
  partititons
* Tue Jul 23 2019 trenn@suse.de
- Update to latest v3.0.0 cobbler release
- Add previouly added patch: exclude_get-loaders_command.patch to
  the list of patches to apply.
* Mon Jun  3 2019 trenn@suse.de
- Fix log file world readable (as suggested by Matthias Gerstner)
  and change file attributes via attr in spec file
- Do not allow get-loaders command (download of third party
  provided network boot loaders we do not trust)
  A exclude_get-loaders_command.patch
- Add apache min version requires to 2.4 (due to mainline commit:
  31a1aa31d26c4a096f0e0
  Remove apache IfVersion tags from apache configs
- Fix Tumbleweed build where python2-Cheetah3 and python3-Cheetah3
  are build for a while by changing (Build- and) Requires from:
  Cheetah3 to python3-Cheetah3
- Setting test package group to a valid one
- Fix test files to be added to test package, not only the directory
- Remove general dir from file section: %%{_datadir}
- Fix test package requires
  missing Requires: python3-pytest python3-pyflakes python3-pycodestyle
- Mainline fixes:
  3172d1df9b9cc8 Add missing help text in redhat_management_key field
  c8f5490e507a72 Set default interface if cobbler system add has no
  - -interface= param
  31a1aa31d26c4a Remove apache IfVersion tags from apache configs
* Thu May 16 2019 trenn@suse.de
- Updated to latest git master branch
  commit d43461b39073ac01a54a3f52be0b133d36cb8061
  Author: Jochen Breuer <jbreuer@suse.de>
  Date:   Fri May 10 16:41:32 2019 +0200
  Remove already mainline patches:
  D fix-login-error.patch
  D remove-newline-from-token.diff
  D fixes-distro-none-case.diff
  D return-the-name-of-the-unknown-method.patch
  D call-with-logger-where-possible.patch
  D fix-http-status-code.patch
  D create-system-directory-at-the-correct-place.patch
  D remodeled-distro-detection.diff
  D disable_nsupdate_enabled_by_default.diff
  D power_system_xmlrpc_api.patch
  D renamed-methods-alias.patch
  D changes-return-to-float.diff
  D revert-redhat-management-removal.patch
  D add-docker-integration-testing.diff
  D refactor-unittest-to-pytest.diff
  D renamed-methods-alias-part2.patch
  D changes-detection-to-distro-like-for-suse-distributions.diff
  D rhn-mngmnt-key-field-fix.diff
* Thu May 16 2019 Jochen Breuer <jbreuer@suse.de>
- Re-enabling build for cobbler-test package.
* Wed May 15 2019 trenn@suse.de
- Integrated fixes that came in from mainline from other products
  (to calm down obs regression checker):
  CVE-2011-4953, fate#312397, bsc#660126, bsc#671212, bsc#672471, bsc#682665
  bsc#687891, bsc#695955, bsc#722443, bsc#722445, bsc#757062, bsc#763610
  bsc#783671, bsc#790545, bsc#796773, bsc#811025, bsc#812948, bsc#842699
  bsc#846580, bsc#869371, bsc#884051, bsc#976826, bsc#984998
  Some older bugs need bnc# references as well:
  bnc#660126, bnc#671212, bnc#672471, bnc#682665
  bnc#687891, bnc#695955, bnc#722443, bnc#722445, bnc#757062, bnc#763610
  bnc#783671, bnc#790545, bnc#796773, bnc#811025, bnc#812948, bnc#842699
  bnc#846580, bnc#869371, bnc#884051
* Thu May  9 2019 Jochen Breuer <jbreuer@suse.de>
- Fix for redhat_management_key not being listed as a choice
  during profile rename (bsc#1134588)
- Added:
  * rhn-mngmnt-key-field-fix.diff
* Tue May  7 2019 Jochen Breuer <jbreuer@suse.de>
- Fixes distribution detection in setup.py for SLESo
- Added:
  * changes-detection-to-distro-like-for-suse-distributions.diff
* Tue May  7 2019 Jochen Breuer <jbreuer@suse.de>
- Moving to pytest and adding Docker test integration
- Added:
  * add-docker-integration-testing.diff
  * refactor-unittest-to-pytest.diff
* Tue May  7 2019 Jochen Breuer <jbreuer@suse.de>
- Additional compatability changes for old Koan versions.
- Modified:
  * renamed-methods-alias-part2.patch
* Tue Apr 30 2019 Jochen Breuer <jbreuer@suse.de>
- Old Koan versions not only need method aliases, but also need
  compatible responses
- Added:
  * renamed-methods-alias-part2.patch
* Tue Apr 23 2019 Enno Gotthold <egotthold@suse.com>
- Add the redhat_managment_* fields again to enable templating in SUMA.
- Added:
  * revert-redhat-management-removal.patch
* Fri Apr  5 2019 Jochen Breuer <jbreuer@suse.de>
- Changes return of last_modified_time RPC to float
- Added:
  * changes-return-to-float.diff
* Thu Apr  4 2019 mantel@suse.de
- provide old name aliases for all renamed methods:
  - get_distro_for_koan     =>  get_distro_as_rendered
  - get_profile_for_koan    =>  get_profile_as_rendered
  - get_system_for_koan     =>  get_system_as_rendered
  - get_repo_for_koan       =>  get_repo_as_rendered
  - get_image_for_koan      =>  get_image_as_rendered
  - get_mgmtclass_for_koan  =>  get_mgmtclass_as_rendered
  - get_package_for_koan    =>  get_package_as_rendered
  - get_file_for_koan       =>  get_file_as_rendered
- Renamed:
  get_system_for_koan.patch => renamed-methods-alias.patch
* Thu Apr  4 2019 mantel@suse.de
- provide renamed method "get_system_for_koan" under old name
  for old clients.
- Added:
  * get_system_for_koan.patch
* Thu Mar 28 2019 Matei <malbu@suse.com>
- Bring back power_system method in the XML-RPC API
- Changed lanplus option to lanplus=true in fence_ipmitool.template
- Added:
  * power_system_xmlrpc_api.patch
- Changed:
  * fence_ipmitool.template
* Wed Mar 27 2019 Jochen Breuer <jbreuer@suse.de>
- Disables nsupdate_enabled by default
- Added:
  * disable_nsupdate_enabled_by_default.diff
* Wed Mar 27 2019 Jochen Breuer <jbreuer@suse.de>
- Fixes issue in distribution detection with "lower" function call.
- Modified:
  * remodeled-distro-detection.diff
* Tue Mar 26 2019 Jochen Breuer <jbreuer@suse.de>
- Adds imporoved distribution detection. Since now all base products
  get detected correctly, we no longer need the SUSE Manager patch.
- Added:
  * remodeled-distro-detection.diff
* Sun Mar 24 2019 Michael Calmer <mc@suse.com>
- fix grub directory layout
- Added:
  * create-system-directory-at-the-correct-place.patch
* Sat Mar 23 2019 Michael Calmer <mc@suse.com>
- fix HTTP status code of XMLRPC service
- Added:
  * fix-http-status-code.patch
* Tue Mar 19 2019 Michael Calmer <mc@suse.com>
- touch /etc/genders when it not exists (bsc#1128926)
- Add patches to fix logging
- Added:
  * return-the-name-of-the-unknown-method.patch
  * call-with-logger-where-possible.patch
* Tue Mar 19 2019 Jochen Breuer <jbreuer@suse.de>
- Switching version schema from 3.0 to 3.0.0
* Tue Mar 12 2019 Jochen Breuer <jbreuer@suse.de>
- Fixes case where distribution detection returns None (bsc#1130658)
- Added:
  * fixes-distro-none-case.diff
* Tue Mar 12 2019 Jochen Breuer <jbreuer@suse.de>
- Removes newline from token, which caused authentication error (bsc#1128754)
- Added:
  * remove-newline-from-token.diff
* Fri Mar  8 2019 Enno Gotthold <egotthold@suse.com>
- Added a patch which fixes an exception when login in with a non-root user.
- Added:
  * fix-login-error.patch
* Fri Mar  8 2019 Enno Gotthold <egotthold@suse.com>
- Added a patch which fixes an exception when login in with a non-root user.
- Added:
  * fix-login-error.patch
* Fri Mar  8 2019 jgonzalez@suse.com
- Remove patch merged at upstream:
  * 0001-return-token-as-string.patch
* Fri Mar  8 2019 Michael Calmer <mc@suse.com>
- change grub2-x86_64-efi dependency to Recommends
* Thu Mar  7 2019 jgonzalez@suse.com
- grub2-i386pc is not really required. Changed to recommended
  to allow building for architectures other than x86_64
* Thu Mar  7 2019 jgonzalez@suse.com
- Use cdrtools starting with SLE-15 and Leap-15 again. (bnc#1081739)
- Update cobbler loaders server hostname (bsc#980577)
- Update outdated apache config (bsc#956264)
- Replace builddate with changelog date to fix build-compare (bsc#969538)
- LOCKFILE usage removed on openSUSE (bnc#714618)
- Power management subsystem completely re-worked to prevent
  command-injection (CVE-2012-2395)
- Removed patch merged at upstream:
  * cobblerd_needs_apache2_service_started.patch
* Fri Mar  1 2019 trenn@suse.de
- Checking bug fixes of released products are in latest develop pkg:
  - remove fix-nameserver-search.fix; bug is invalid (bsc#1029276)
  - > not needed anymore
  - fix cobbler yaboot handling (bsc#968406, bsc#966622)
  - > no yaboot support anymore
  - support UEFI boot with cobbler generated tftp tree (bsc#1020376)
  - > upstream
  - Enabling PXE grub2 support for PowerPC (bsc#986978)
  - > We have grub2 support for ppc64le
  - (bsc#1048183) fix missing args and location for xen
  - > is in
  - no koan support anymore:
    bsc#969541, bsc#924118, bsc#967523
  - not installed (bsc#966841)
    works.
- These still have to be looked at:
  SUSE system as systemd only (bsc#952844)
  handle list value for kernel options
  correctly (bsc#973413)
  entry in pxe menu (bsc#988889)
- This still has to be switched off (at least in internal cobbler versions):
  Disabling 'get-loaders' command and 'check' fixed. bsc#973418
* Thu Feb 28 2019 trenn@suse.de
- Add python3-requests and removed old python2 requires:
  Requires:       python-PyYAML
  Requires:       python-urlgrabber
  (originally from jbreuer@suse.de)
- Add explicity require to tftp, so it is used for both SLE
  and openSUSE (originally from jgonzalez@suse.com)
- Moved Recommends according to spec_cleaner
* Mon Feb 25 2019 trenn@suse.de
- Require latest apache2-mod_wsgi-python3 package
  This fixes interface to http://localhost/cblr/svc/...
- Use latest github cobbler/cobbler master branch in _service file
- cobblerd_needs_apache2_service_started.patch reverted, that is mainline
  now:
  D cobblerd_needs_apache2_service_started.patch
- Only recommend grub2-arm and grub2-ppc packages or we might not be
  able to build on factory where arm/ppc might not be built
- Remove genders package requires. A genders file is generated, but
  we do not need/use the genders package.
* Tue Feb 19 2019 Ismail Dönmez <idonmez@suse.com>
- Cleanup with spec-cleaner
* Thu Feb 14 2019 trenn@suse.de
- Update to latest cobbler version 3.0 mainline git HEAD version
  and remove already integrated or not needed anymore patches:
  D    cobbler-symlink.diff
  D    detect-parallel-cobbler-sync.patch
  D    escape-shell-parameters-provided-by-user-on-reposync.patch
  D    fix_subprocess_sp_encoding.patch
  D    fix-os-release.patch
  D    disable_not_relevant_checks_bnc_828453.patch
  D    update-outdated-apache-config-bsc956264.patch
  D    cve-2018-10931-forbid-exposure-of-private-methods-in.patch
  D    fix-broken-tests.diff
  D    fix-manpage-creation.patch
  D    do_not_use_grubby_compat_when_grub2_is_in_use.diff
  D    fix_hardcoded_libpath_for_websession.patch
  D    looking_for_cobbler_order_changed.diff
  D    grubby-compat.diff
  D    fix-restart-paravirt-xen.dif
  D    koan_old_cobbler_compat.diff
  D    fix_shebang.patch
  D    catch_cheetah_exception.patch
  D    fix-script-endpoint-security-bug-1030582.patch
  D    cobbler_web_config.diff
  D    fix-koan-port-guessing.dif
  D    cobblerd_needs_apache2_service_started.patch
  D    fix-powermanagement-status.dif
  D    check-access-token-when-calling-modify_setting-api-e.patch
  D    fix_sle_detection.patch
  D    fix_test_create_systems.diff
  D    fix_subprocess_sp_encoding.patch
  D    cobbler-2.4.2-reprovision-rhel-on-suse-bnc883487.patch
* Wed Feb  6 2019 trenn@suse.de
- Serial console support added, did some testing already
  Things should start to work as expected
* Tue Jan 29 2019 trenn@suse.de
- Add general grub2 support
* Wed Jan 16 2019 trenn@suse.de
- Put mkgrub.* into mkgrub.sh
* Wed Jan 16 2019 trenn@suse.de
- Add git date and commit to version string for now
* Wed Jan 16 2019 trenn@suse.de
- Add grub2 mkimage scripts:
  mkgrub.i386-pc
  mkgrub.powerpc-ieee1275
  mkgrub.x86_64-efi
  mkgrub.arm64-efi
  and generate grub executables with them in the %%post section
* Fri Jan 11 2019 trenn@suse.de
  * * Backported fixes from SLE12 SP3
- build server wants explicite package in BuildRequires; use tftp
- require tftp(server) instead of atftp
- cleanup: cobbler is noarch, so arch specific requires do not make
  sense
- SLES15 is using /etc/os-release instead of /etc/SuSE-release, use
  this one for checking also
- Add:
  * sles15.patch
- add sles15 distro profile (bsc#1090205)
- Add:
  * add-sles15-distro.patch
- fix signature for SLES15 (bsc#1075014)
- Updated:
  * add-sles15-distro.patch
- fix signature for SLES15 (bsc#1075014)
- Updated:
  * add-sles15-distro.patch
  Missing fixes
  =============
  This SLE fixes are missing.
  The reason for this is that koan got split out into a separate
  package, these changes (changelog entries) therefore are not relevant
  for this package anymore:
  Koan specific:
- fix koan wait parameter initialization
  Added:
  * fix-wait.patch
- Fix koan shebang
- Add:
  * fix-usr-bin-env-bash-koan.diff
  But these patches still have to be double checked and
  probably applied to current cobbler sources.
  The patches are still added in the package, but do not
  get patched. If this work has been done, these changelog
  entries should show up in the
  * * Backported fixes from SLE12 SP3
  section above to please maintenance and "factory first"
  release checking tools:
  cobbler specific (still have to be done):
- Escape shell parameters provided by the user for the
  reposync action (CVE-2017-1000469) (bsc#1074594)
- Added:
  * escape-shell-parameters-provided-by-user-on-reposync.patch
- detect if there is already another instance of "cobbler sync"
  running and exit with failure if so (bsc#1081714)
- Add:
  * detect-parallel-cobbler-sync.patch
- do not try to hardlink to a symlink. The result will be a
  dangling symlink in the general case (bsc#1097733)
- Added:
  * cobbler-symlink.diff
- fix kernel options when generating bootiso (bsc#1101670)
- Added:
  * cobbler-buildiso-list-to-string.patch
- Refreshed:
  * cobbler-symlink.diff
- fix service restart after logrotate for cobblerd (bsc#1113747)
- rotate cobbler logs at higher frequency to prevent disk fillup
  (bsc#1113747)
* Fri Aug 10 2018 pablo.suarezhernandez@suse.com
- Forbid exposure of private methods in the API (CVE-2018-10931)
  (CVE-2018-1000225) (bsc#1104287) (bsc#1104189) (bsc#1105442)
- Check access token when calling 'modify_setting' API endpoint
  (bsc#1104190) (bsc#1105440) (CVE-2018-1000226)
- Added:
  * check-access-token-when-calling-modify_setting-api-e.patch
  * cve-2018-10931-forbid-exposure-of-private-methods-in.patch
* Thu Apr 26 2018 pablo.suarezhernandez@suse.com
- Escape shell parameters provided by the user for the
  reposync action (CVE-2017-1000469) (bsc#1074594)
- Added:
  * escape-shell-parameters-provided-by-user-on-reposync.patch
* Mon Mar  5 2018 adam.majer@suse.de
- Use cdrtools starting with SLE-15 and Leap-15 again.
  (bnc#1081739)
* Mon Nov 27 2017 pablo.suarezhernandez@suse.com
- Cleanup of the spec file.
* Mon Nov 27 2017 jloeser@suse.com
- fix creation of manpages:
    option '--release ""' resulted in empty man pages
- added patch:
  * fix-manpage-creation.patch
* Wed Nov  8 2017 aavindraa@gmail.com
- Update to latest stable version of cobbler (2.8.2)
  * many changes since 2.6.6. see: https://cobbler.github.io/posts/
- rebase patches
  * koan_old_cobbler_compat.diff
  * disable_not_relevant_checks_bnc_828453.patch
  * update-outdated-apache-config-bsc956264.patch
    + potentionally fixed in 3d4db162c7b7c0fe7de00c30fcb81798b7db5039
- remove fix-cobbler-loaders-server-bsc980577.patch
  * fixed in 77328c0b05d37878f13704efa31e4daa162fda12
- remove vendor-files.tar.bz2
  * use built in manpage instead of vendored one
  * add cobbler_firewall_settings to package root
- use py macros to do installation
* Thu Oct  5 2017 mihai.dinca@suse.com
- fix script endpoint security bug CVE-2016-9605 (bsc#1030582)
  Add:
  * fix-script-endpoint-security-bug-1030582.patch
* Wed Oct  4 2017 mihai.dinca@suse.com
- fix setup.py to identify SUSE OS correctly bsc#1046679
  Added:
  * fix-os-release.patch
* Fri Jul 28 2017 trenn@suse.de
- Recommend fence-agents for broader power switch support
* Wed May 18 2016 pablo.suarezhernandez@suse.com
- Update cobbler loaders server hostname bsc#980577
  Added:
  * fix-cobbler-loaders-server-bsc980577.patch
* Tue May  3 2016 mdinca@suse.de
- Update outdated apache config bsc#956264
  * update-outdated-apache-config-bsc956264.patch
* Wed Mar  9 2016 bwiedemann@suse.com
- Replace builddate with changelog date to fix build-compare (bsc#969538)
* Thu Jan 15 2015 fcastelli@suse.com
- Added 'fix_test_create_systems.diff': fixes the "create_systens" unit test
* Tue Jan 13 2015 fcastelli@suse.com
- Fix runtime dependency: ensure the yaml module is available.
* Tue Jan 13 2015 fcastelli@suse.com
- Install the right cobblerd.service file
* Mon Jan 12 2015 fcastelli@suse.com
- Do not ship cobbler_web.conf inside of the cobbler package, get rid
  of part of our patches to setup.py,
* Fri Dec 19 2014 fcastelli@suse.com
- Added new patch required to fix the broken unit tests:
  * fix-broken-tests.diff
* Thu Dec 18 2014 fcastelli@suse.com
- Removed another no longer needed patch:
  * fix-textmode-for-SUSE.dif
* Thu Dec 18 2014 fcastelli@suse.com
- Update to latest stable version of cobbler (2.6.6)
- Removed no longer needed patches
  * bnc_877009.patch
  * cobbler-2.4.2-Fix-koan-s-get_insert_script.patch
  * fix-broken-tests.diff
  * fix-initscript.diff
  * suse_config.diff
- Fixed old patches to apply against the new code:
  * catch_cheetah_exception.patch
  * grubby-compat.diff
  * setup_py.diff
* Mon Dec 15 2014 fcastelli@suse.com
- Fix the broken unit tests
* Thu Dec 11 2014 mseidl@suse.de
- Created sub package for unit tests
* Tue Dec  9 2014 mc@suse.de
- use fdupes only on SUSE
* Mon Dec  8 2014 dmacvicar@suse.de
- Fix for re-installation of machines on SLE with static
  network configuration (bnc#883487)
- Added patches:
  * cobbler-2.4.2-Fix-koan-s-get_insert_script.patch
  * cobbler-2.4.2-reprovision-rhel-on-suse-bnc883487.patch
* Thu Nov 27 2014 mc@suse.de
- fix port guessing in koan (bsc#855389)
  * fix-koan-port-guessing.dif
- add "copy-default" option to grubby-compat (bsc#855389)
- handle elilo in SUSE (bsc#855389)
* Wed Nov 26 2014 mc@suse.de
- fix wrong option "text" in SUSE environment (bsc#901058)
  * fix-textmode-for-SUSE.dif
* Thu Sep  4 2014 fcastelli@suse.com
- Added do_not_use_grubby_compat_when_grub2_is_in_use.diff: prevents
  usage of grubby-compat when grub2 is active. Use grub2 features
  do modify the boot loader.
* Tue Sep  2 2014 fcastelli@suse.com
- Moved grubby-compat inside of the koan sub-package. The scrit was accidentally
  moved into the cobbler package.
* Fri Jul 25 2014 fcastelli@suse.com
- Added fix_sle_detection.patch: ensures SLE12 is properly detected.
* Fri Jul 25 2014 fcastelli@suse.com
- Did some cleanup of the spec file.
* Tue Jul 15 2014 fcastelli@suse.com
- Fix source of cobbler package inside of spec file (required by openSUSE:Factory)
* Tue Jul 15 2014 fcastelli@suse.com
- Added bnc_877009.patch, fixes CVE-2014-3225: cobbler: Local file inclusion (bnc#877009)
* Mon Jul 14 2014 fcastelli@suse.com
- Got rid of some of the rpmlint warnings.
- Fixed error inside of koan tool introduced by the 'grubby-compat.diff' patch.
* Fri Jul 11 2014 mseidl@suse.de
- Requires tfpt-server but atftp/tftpt packages provide tfpt(server)
- Added conditional requires for s390x and syslinux-x86_64
- Added patches:
  + catch_cheetah_exception.patch
  - forward cheetah exception as 500 SERVER ERROR (bnc#787879)
  + disable_not_relevant_checks_bnc_828453.patch
  + fence_ipmitool.sh
  - add fence_ipmitool script for power management
  + fix-powermanagement-status.dif
  - fix evaluation of power status calls
  + fix-restart-paravirt-xen.dif
  - fix XEN fullvirt installation
  + grubby-compat.diff
  + koan_old_cobbler_compat.diff
  - add new grubby-compat tool
  + looking_for_cobbler_order_changed.diff
  - fix cobbler checks on SUSE (bnc#828453)
  + setup_py.diff
  - update paths for suse apache
- Modified fix-initscript.diff -Failed to patch due to new line in newer version
- Removed patches:
  - suse_newver.patch - Upstreamed
  - users_patch.diff - Upstreamed
  - cheetah_template_autoescape.patch - No longer needed
* Fri Feb 14 2014 mc@suse.de
- update to version 2.4.2
  + Adding support for gPXE
  + Adding support for ESXi5
  + fix install=... kernel parameter when importing a SUSE distro
  + koan: Port xen creation to virt-install
  + koan: Port qcreate to virt-install
  + Port koan from virtinst to virt-install command (v2)
  + add qcow2 driver type
  + Adding ability to use https for API calls (cobbler CLI)
  + Use ip instead of ifconfig for network snippets
  + minor modifications to templar to show template rendering errors
  + bugfixes and refactoring
* Tue Aug 13 2013 kkaempf@suse.com
- Update to 2.4.0
  Major Features:
  - Dynamic Settings
  - Distro Signatures
  - Vastly improved support for Ubuntu, OpenSUSE and VMware ESXi (5.0 and 5.1)
  - Added in new templated scripting support (needs documentation)
  - New web interface improvements (tabs, etc.)
  - Added apt-specific fields for repositories to make mirroring them easier
  - Support for parameterized classes and defines in puppet using management classes
  Minor Features:
  - Added the bonded_bridge_slave interface type:
  - Improved template error reporting
  - Variables in fields are now evaluated through the templating engine
  - Added openvz as a virtualization type for koan
  - Added --virt-pxe-boot option for koan to force PXE booting of new systems
  - Added a per-interface gateway option, for systems that support it
  - Added support for new puppet command syntax
  - Exposed replication rsync options
  Major Bugfixes:
  - --available-as no longer copies all files.
  - Improved gPXE/iPXE support, including FreeBSD
  - Deleting objects now respects the --recursive option again
  Minor Bugfixes:
  - Too many to list
* Wed Aug  7 2013 ro@suse.de
- fix filelist to fix build on factory: rpm does not allow to
  mark a non-directory as dir anymore
* Wed Apr 10 2013 rbrownccb@opensuse.org
- use systemd for openSUSE 12.3 and later
- change release number to match upstream
- drop obsolete setup_py.diff
- add required apache modules for cobbler-web
- add suse_newver.patch to add support for SLES11 SP3,
  openSUSE 12.3 and openSUSE 13.1
* Tue Apr  9 2013 rbrownccb@opensuse.org
- update to 2.2.3
  + Multiple security fixes
  + CSRF support for the web GUI, which will now default to using
    https too.
  + Power management subsystem completely re-worked to prevent
    command-injection (CVE-2012-2395)
  + Support for bind in chroot'd environments
  + Koan now uses virt-install CLI instead of directly accessing
    the virtinst API
  + Various improvements for SuSE and autoyast, especially for
    PPC64-based systems.
  + BETA support for ESXi5 and gPXE
  + BETA support for using other template languages, like jinja2
- rebase patches
- drop obsolete manage_import_suse.py
- no longer requires mod_python
* Thu May  3 2012 ug@suse.de
- require syslinux only on x86 arch
* Thu Apr 19 2012 ug@suse.de
- moved the secret generation from RPM post-script to the
  init-script, to avoid that all appliances will still have the
  same key
* Tue Apr 17 2012 ug@suse.de
- create a secret during installation
* Tue Mar 27 2012 chris@computersalat.de
- update to 2.2.2
  * please see CHANGELOG for more info
- remove obsolete virt-auto-boot patch
- rebase patches
* Mon Feb 13 2012 ug@suse.de
- fixed return value of rccobblerd status
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Thu Dec 22 2011 ug@suse.de
- fix install=... kernel option when you import a SUSE distro
* Wed Oct 26 2011 ug@suse.de
- virtual machines autostart on boot fixed
* Fri Oct  7 2011 ug@suse.de
- Import modules, which allowed easy integration of...
- Ubuntu and Debian support again!
- Better support for SuSE
- Support for FreeBSD
- Support for ESX 4+/ESXi
- Integration with the python TFTP server pytftpd
- "fetchable files" and "boot files" support for distros that need to
  get more files from the TFTP server
- Faster sync using link cache
- Support for EFI grub booting
- Support for bridged interfaces
- WSGI instead of mod_python for the web interface.
- Lots of Web UI improvements
- A lot more I'm sure I missed when going through the change log
- version 2.2.1
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Wed Aug 31 2011 ug@suse.de
- LOCKFILE usage removed on openSUSE
  (bnc#714618)
* Fri Jun 10 2011 ug@suse.de
- fixed the handling of cheetah template code in
  AutoYaST XML files
  (thanks to Jörgen Maas for pointing me to the bug)
- fixed parameter list in build-ISO code
  (thanks to Jörgen Maas for the patch)
* Thu Apr  7 2011 ug@suse.de
- added a backported upstream patch for tainted file error
  message
* Thu Apr  7 2011 ug@suse.de
- fix hostname in install=...
* Thu Apr  7 2011 ug@suse.de
- fix init-script
* Thu Apr  7 2011 ug@suse.de
- fixed apache config typo
* Wed Apr  6 2011 ug@suse.de
- added SUSE breed to import-webui
* Wed Apr  6 2011 ug@suse.de
- build ISO for SUSE fixed
* Wed Apr  6 2011 ug@suse.de
- added patch for autoyast XML files and cobbler triggers
* Wed Apr  6 2011 ug@suse.de
- added patch to fix koan with SUSE dists
* Tue Apr  5 2011 ug@suse.de
- fixed tftp-root path on SUSE
* Tue Apr  5 2011 ug@suse.de
- added support for importing a SUSE distribution
* Mon Apr  4 2011 ug@suse.de
- fixed the start of cobblerd when [tftpd] section is missing
  in the modules.conf
* Mon Apr  4 2011 ug@suse.de
- version from 2.0.10 to 2.1.0
* Wed Mar 23 2011 ug@suse.de
- changed logfiles to root:root (bnc#678433)
* Tue Mar 22 2011 ug@suse.de
- changed permissions in /var/log/ to root:www (bnc#678433)
* Fri Mar  4 2011 ug@suse.de
- patches cleaned up
* Mon Feb 28 2011 ug@suse.de
- fixed a crash because xml.dom.ext is not available on 11.4
* Thu Feb 17 2011 ug@suse.de
- fixed the restarting of services on SUSE
* Thu Feb 17 2011 ug@suse.de
- missing rc-script link added
* Wed Feb 16 2011 ug@suse.de
- don't add "#raw" comment per default anymore
* Wed Feb 16 2011 ug@suse.de
- cobbler failed to export kickstart profiles with $SNIPPET(...)
  cheetah_class_fix.diff added for that
* Tue Feb  8 2011 ug@suse.de
- removed grubby from the requires
* Thu Feb  3 2011 ug@suse.de
- packaged the cobbler.conf instead of cobbler_wsgi.conf
  (bnc#668968)
* Wed Feb  2 2011 ug@suse.de
- spec file fixed
* Fri Jan 28 2011 ug@suse.de
- fixed apache config to avoid warning
* Wed Jan 19 2011 ug@suse.de
- added firewall config
* Thu Jan 13 2011 ug@suse.de
- version update to 2.0.10
* Wed Jan 12 2011 ug@suse.de
- some template files were not packaged
* Tue Jan 11 2011 ug@suse.de
- removed xinetd from start script
* Tue Jan 11 2011 ug@suse.de
- update to version 2.0.8
